/**********************************************************************/
/*
     FILE: cwfdim.c
  PURPOSE: To print the length of a dimension from a CoastWatch format file.
   AUTHOR: Peter Hollemans
     DATE: 24/06/1998
  CHANGES: 01/09/1998, PFH, changed format of dimension list

  CoastWatch Format (CWF) Software Library and Utilities
  Copyright 1998, USDOC/NOAA/NESDIS CoastWatch West Coast Regional Node

*/
/**********************************************************************/

/* include files */

#include <stdio.h>
#include <stdlib.h>
#include "cwf.h"

/* defined constants */

#define UMESSAGE "\
usage: cwfdim [-d dimension] input\n\
where: -d dimension     The dimension to print.  If not specified, a list\n\
                        of valid dimension names is printed.\n\
       input            The CoastWatch dataset to read.\n"

#define NARG	1

/* defined macros */

#define XIT(m,v,e) { \
  err ((m), (v)); \
  exit ((e)); \
} 

#define STR(e) cw_strerror ((e))

static int cwerr;
#define CHK(r,v) { \
  if ((cwerr = (r)) != CW_NOERR) \
    XIT (STR (cwerr), (v), cwerr); \
} 

/**********************************************************************/

void err (const char *m, const char *v) {
  fprintf (stderr, "cwfdim: %s: %s\n", v, m);
} /* err */

/**********************************************************************/

void usage (int ecode) {
  fprintf (stderr, UMESSAGE);
  exit (ecode);
} /* usage */

/**********************************************************************/

int main (int argc, char *argv[]) {

size_t dim_len;
int cwid, varid, ndims, dimids[CW_MAX_VAR_DIMS];
char dim_name[CW_MAX_NAME];
int list = 1;
int i;
char cbuf[32];

  argc--, argv++;				/* parse command line */
  if (argc < NARG)
    usage (-1);
  while (argv[0][0] == '-') {
    switch (argv[0][1]) {
      case 'd':
        strcpy (dim_name, argv[1]);
        list = 0;
        argc-=2, argv+=2; 
        break;
      default: 
        err ("invalid option", argv[0]); 
        usage (-2);
    } /* switch */
    if (argc < NARG)
      usage (-3);
  } /* while */

						/* open file */
  CHK (cw_open (argv[0], CW_NOWRITE, &cwid), argv[0]);

  varid = 0;					/* get variable info */
  CHK (cw_inq_var (cwid, varid, NULL, NULL, &ndims, dimids, NULL), 
    "variable 0");

  if (list) {					/* list dimensions */
    for (i = 0; i < ndims; i++) {
      sprintf (cbuf, "dimension %d", i);
      CHK (cw_inq_dim (cwid, dimids[i], dim_name, NULL), cbuf);
      printf ("%s\n", dim_name);
    } /* for */
  } /* if */
  else {
    CHK (cw_inq_dimid (cwid, dim_name, dimids), dim_name);
    CHK (cw_inq_dim (cwid, dimids[0], NULL, &dim_len), dim_name);
    printf ("%d\n", (int) dim_len);
  } /* else */

  CHK (cw_close (cwid), argv[0]);		/* finish up */
  return (CW_NOERR);

} /* main */

/**********************************************************************/
